@@ -22,8 +22,8 @@ class FeaturesAndLabels(object):
     """
 
     def __init__(self,
-                 features: Typing._Selector,
-                 labels: Typing._Selector,
+                 features: Union[Typing._Selector,Tuple[Typing._Selector]],
+                 labels: Typing._Selector = [],
                  sample_weights: Typing._Selector = None,
                  gross_loss: Typing._Selector = None,
                  targets: Typing._Selector = None,
@@ -125,6 +125,11 @@ class FeaturesAndLabels(object):
         copy._sample_weights = sample_weights
         return copy
 
+    def with_gross_loss(self, gross_loss: Union[str, List[T], Callable[[Any], Union[pd.DataFrame, pd.Series]]]):
+        copy = deepcopy(self)
+        copy._gross_loss = gross_loss
+        return copy
+
     def with_kwargs(self, **kwargs):
         copy = deepcopy(self)
         copy.kwargs = {**self.kwargs, **kwargs}
