@@ -1,5 +1,5 @@
 from .splitter import Splitter
 from .random_splits import RandomSplits
 from .random_sequences import RandomSequences
-from .naive import NaiveSplitter
+from .naive import NaiveSplitter, TimeSeriesSplitter
 from .dummy import DummySplitter
\ No newline at end of file
