@@ -1,7 +1,11 @@
+import importlib.util as _ilu
+
+from .auto_encoder_model import AutoEncoderModel
 from .base_model import Model
-from .scikit_learn_model import SkModel
 from .keras_model import KerasModel
 from .multi_model import MultiModel
 from .pytoch_model import PytorchModel
-from .reinforcement_model import ReinforcementModel
-from .auto_encoder_model import AutoEncoderModel
+from .scikit_learn_model import SkModel
+
+if _ilu.find_spec("gym"):
+    from .reinforcement_model import ReinforcementModel
