@@ -1,5 +1,3 @@
-import os
-
 import pandas_ml_utils.html as html
 from pandas_ml_common import Typing
 
@@ -12,8 +10,9 @@ class Summary(object):
      * implement `_repr_html_()`
     """
 
-    def __init__(self, df: Typing.PatchedDataFrame, **kwargs):
+    def __init__(self, df: Typing.PatchedDataFrame, model: 'Model', **kwargs):
         self._df = df
+        self.model = model
         self.kwargs = kwargs
 
     @property
